@@ -5,7 +5,7 @@ use warnings;
 use base 'HTML::Parser';
 use HTML::Filter::Callbacks::Tag;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my %Handlers = (
   start => [\&_handler, 'self,event,tokens,text,skipped_text'],
@@ -42,7 +42,7 @@ sub add_callbacks {
   while (my ($tag, $handlers) = splice @callbacks, 0, 2) {
     foreach my $event (keys %$handlers) {
       my $cb = $handlers->{$event};
-      push @{ $self->{__cb}{lc $tag}{$event} ||= [] }, $cb unless $self->{__seen}{$cb}++;
+      push @{ $self->{__cb}{lc $tag}{$event} ||= [] }, $cb unless $self->{__seen}{$event}{$cb}++;
     }
   }
 }
